@@ -17,6 +17,7 @@
  */
 package org.apache.phoenix.end2end;
 
+import static org.apache.phoenix.exception.SQLExceptionCode.CANNOT_MUTATE_TABLE;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.COLUMN_FAMILY;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.COLUMN_NAME;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.COLUMN_QUALIFIER;
@@ -46,11 +47,11 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Properties;
 
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
+import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.jdbc.PhoenixConnection;
@@ -240,8 +241,8 @@ public class AlterTableIT extends ParallelStatsDisabledIT {
         try {
             conn.createStatement().execute(ddl);
             conn.createStatement().execute("ALTER TABLE " + dataTableFullName + " ADD CF.col2 integer CF.IN_MEMORY=true");
-            try (HBaseAdmin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
-                HColumnDescriptor[] columnFamilies = admin.getTableDescriptor(Bytes.toBytes(dataTableFullName)).getColumnFamilies();
+            try (Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
+                ColumnFamilyDescriptor[] columnFamilies = admin.getDescriptor(TableName.valueOf(dataTableFullName)).getColumnFamilies();
                 assertEquals(2, columnFamilies.length);
                 assertEquals("0", columnFamilies[0].getNameAsString());
                 assertFalse(columnFamilies[0].isInMemory());
@@ -859,9 +860,9 @@ public class AlterTableIT extends ParallelStatsDisabledIT {
     @Test
     public void testAlterTableOnGlobalIndex() throws Exception {
         try (Connection conn = DriverManager.getConnection(getUrl());
-             HBaseAdmin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin();
              Statement stmt = conn.createStatement()) {
             conn.setAutoCommit(false);
+            Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin();
             String tableName = generateUniqueName();
             String globalIndexTableName = generateUniqueName();
 
@@ -869,17 +870,17 @@ public class AlterTableIT extends ParallelStatsDisabledIT {
                 " (ID INTEGER PRIMARY KEY, COL1 VARCHAR(10), COL2 BOOLEAN)");
 
             stmt.execute("CREATE INDEX " + globalIndexTableName + " on " + tableName + " (COL2)");
-            HTableDescriptor originalDesc = admin.getTableDescriptor(Bytes.toBytes(globalIndexTableName));
-
+            TableDescriptor originalDesc = admin.getDescriptor(TableName.valueOf(globalIndexTableName));
+            int expectedErrorCode = 0;
             try {
                 stmt.execute("ALTER TABLE " + globalIndexTableName + " ADD CF1.AGE INTEGER ");
                 conn.commit();
                 fail("The alter table did not fail as expected");
             } catch (SQLException e) {
-                assertEquals(e.getErrorCode(), SQLExceptionCode.CANNOT_MUTATE_TABLE.getErrorCode());
+                assertEquals(e.getErrorCode(), CANNOT_MUTATE_TABLE.getErrorCode());
             }
 
-            HTableDescriptor finalDesc = admin.getTableDescriptor(Bytes.toBytes(globalIndexTableName));
+            TableDescriptor finalDesc = admin.getDescriptor(TableName.valueOf(globalIndexTableName));
             assertTrue(finalDesc.equals(originalDesc));
 
             // drop the table
@@ -958,8 +959,7 @@ public class AlterTableIT extends ParallelStatsDisabledIT {
             // set HColumnProperty property when adding a pk column and other key value columns should work
             ddl = "ALTER TABLE "
                     + dataTableFullName
-                    + " ADD k3 DECIMAL PRIMARY KEY, col2 bigint, CF.col3 bigint IN_MEMORY = true,"
-                    + " CF.IN_MEMORY=false, REPLICATION_SCOPE = 1";
+                    + " ADD k3 DECIMAL PRIMARY KEY, col2 bigint, CF.col3 bigint IN_MEMORY = true, CF.IN_MEMORY=false, REPLICATION_SCOPE = 1";
             conn.createStatement().execute(ddl);
             // assert that k3 was added as new pk
             ResultSet rs = conn.getMetaData().getPrimaryKeys("", schemaName, dataTableName);
@@ -974,9 +974,9 @@ public class AlterTableIT extends ParallelStatsDisabledIT {
             assertEquals(3, rs.getShort("KEY_SEQ"));
             assertFalse(rs.next());
 
-            try (HBaseAdmin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
-                HTableDescriptor tableDesc = admin.getTableDescriptor(Bytes.toBytes(dataTableFullName));
-                HColumnDescriptor[] columnFamilies = tableDesc.getColumnFamilies();
+            try (Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
+                TableDescriptor tableDesc = admin.getDescriptor(TableName.valueOf(dataTableFullName));
+                ColumnFamilyDescriptor[] columnFamilies = tableDesc.getColumnFamilies();
                 assertEquals(2, columnFamilies.length);
                 assertEquals("0", columnFamilies[0].getNameAsString());
                 assertEquals(true, columnFamilies[0].isInMemory());
@@ -1488,18 +1488,16 @@ public class AlterTableIT extends ParallelStatsDisabledIT {
         String tableName2 = generateUniqueName();
         Properties props = PropertiesUtil.deepCopy(TestUtil.TEST_PROPERTIES);
         try (Connection conn = DriverManager.getConnection(getUrl(), props);
-            Statement stmt = conn.createStatement()) {
+          Statement stmt = conn.createStatement()) {
             conn.setAutoCommit(false);
 
-            String ddl = "CREATE TABLE " + tableName1 + " (id VARBINARY PRIMARY KEY, "
-                + "col1 INTEGER)";
+            String ddl = "CREATE TABLE " + tableName1 + " (id VARBINARY PRIMARY KEY, col1 INTEGER)";
             stmt.execute(ddl);
 
             String alterDdl = "ALTER TABLE " + tableName1 + " ADD col2 INTEGER";
             stmt.execute(alterDdl);
 
-            String ddl2 = "CREATE TABLE " + tableName2 + " (id INTEGER ARRAY PRIMARY KEY, "
-                + "col1 INTEGER)";
+            String ddl2 = "CREATE TABLE " + tableName2 + " (id INTEGER ARRAY PRIMARY KEY, col1 INTEGER)";
             stmt.execute(ddl2);
 
             String alterDdl2 = "ALTER TABLE " + tableName2 + " ADD col2 INTEGER";
@@ -1576,4 +1574,4 @@ public class AlterTableIT extends ParallelStatsDisabledIT {
         }
     }
 
-}
+}
\ No newline at end of file
