@@ -37,11 +37,14 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
+import java.util.Optional;
 import java.util.Properties;
 
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.PhoenixTagType;
+import org.apache.hadoop.hbase.PrivateCellUtil;
+import org.apache.hadoop.hbase.RawCell;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.Tag;
 import org.apache.hadoop.hbase.client.Scan;
@@ -57,7 +60,6 @@ import org.apache.phoenix.query.ConnectionQueryServices;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.QueryUtil;
-import org.junit.Assert;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
@@ -1070,6 +1072,7 @@ public class DeleteIT extends ParallelStatsDisabledIT {
                         "upsert into " + tableName + " values (2, 'bar', 'bar1')");
                 conn.commit();
             }
+
         }
     }
 
@@ -1097,7 +1100,7 @@ public class DeleteIT extends ParallelStatsDisabledIT {
             Scan scan = new Scan();
             // Make sure to set rawScan to true so that we will get Delete Markers.
             scan.setRaw(true);
-            scan.setStartRow(Bytes.toBytes(startRowKey));
+            scan.withStartRow(Bytes.toBytes(startRowKey));
             RegionScanner scanner = region.getScanner(scan);
             scanner.next(values);
             if (!values.isEmpty()) {
@@ -1107,14 +1110,14 @@ public class DeleteIT extends ParallelStatsDisabledIT {
         assertFalse("Values shouldn't be empty", values.isEmpty());
         Cell first = values.get(0);
         assertTrue("First cell should be delete marker ", CellUtil.isDelete(first));
-        List<Tag> tags = Tag.asList(first.getTagsArray(),
-                first.getTagsOffset(), first.getTagsLength());
+        List<Tag> tags = PrivateCellUtil.getTags(first);
         if (tagPresent) {
             assertEquals(1, tags.size());
-            Tag sourceOfOperationTag = Tag.getTag(first.getTagsArray(), first.getTagsOffset(),
-                    first.getTagsLength(), PhoenixTagType.SOURCE_OPERATION_TAG_TYPE);
-            Assert.assertNotNull(sourceOfOperationTag);
-            assertEquals(tagValue, Bytes.toString(sourceOfOperationTag.getValue()));
+            RawCell rawCell = (RawCell)first;
+            Optional<Tag> optional = rawCell.getTag(PhoenixTagType.SOURCE_OPERATION_TAG_TYPE);
+            assertTrue(optional.isPresent());
+            Tag sourceOfOperationTag = optional.get();
+            assertEquals(tagValue, Tag.getValueAsString(sourceOfOperationTag));
         } else {
             assertEquals(0, tags.size());
         }
