@@ -17,11 +17,13 @@
  */
 package org.apache.phoenix.end2end;
 
-import com.google.common.collect.Maps;
-import org.apache.commons.lang.StringUtils;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.end2end.index.IndexCoprocIT;
 import org.apache.phoenix.hbase.index.IndexRegionObserver;
 import org.apache.phoenix.hbase.index.Indexer;
@@ -202,7 +204,7 @@ public class ParameterizedIndexUpgradeToolIT extends BaseTest {
         TRANSACTIONAL_TABLE_LIST[0] = transactTable;
         conn.createStatement().execute("CREATE TABLE " + transactTable + " (id bigint NOT NULL "
                         + "PRIMARY KEY, a.name varchar, sal bigint, address varchar) "
-                + " TRANSACTIONAL=true "
+                + " TRANSACTIONAL=true, TRANSACTION_PROVIDER='OMID' "
                 + ((tableDDLOptions.trim().length() > 0) ? "," : "") + tableDDLOptions);
 
         String mockOneViewOne = "TEST." + generateUniqueName();
@@ -393,7 +395,7 @@ public class ParameterizedIndexUpgradeToolIT extends BaseTest {
         if (mutable) {
             for (String table : tableList) {
                 if (table != null) {
-                    HTableDescriptor indexDesc = admin.getTableDescriptor(TableName.valueOf(table));
+                    TableDescriptor indexDesc = admin.getDescriptor(TableName.valueOf(table));
                     Assert.assertTrue("Can't find IndexRegionObserver for " + table,
                         indexDesc.hasCoprocessor(IndexRegionObserver.class.getName()));
                     Assert.assertFalse("Found Indexer on " + table,
@@ -402,11 +404,10 @@ public class ParameterizedIndexUpgradeToolIT extends BaseTest {
                         IndexCoprocIT.INDEX_REGION_OBSERVER_CONFIG);
                 }
             }
-
         }
         for (String index : indexList) {
             if (index != null) {
-                HTableDescriptor indexDesc = admin.getTableDescriptor(TableName.valueOf(index));
+                TableDescriptor indexDesc = admin.getDescriptor(TableName.valueOf(index));
                 Assert.assertTrue("Couldn't find GlobalIndexChecker on " + index,
                     indexDesc.hasCoprocessor(GlobalIndexChecker.class.getName()));
                 IndexCoprocIT.assertCoprocConfig(indexDesc, GlobalIndexChecker.class.getName(),
@@ -416,16 +417,16 @@ public class ParameterizedIndexUpgradeToolIT extends BaseTest {
         // Transactional indexes should not have new coprocessors
         for (String index : TRANSACTIONAL_INDEXES_LIST) {
             if (index != null) {
-                Assert.assertFalse("Found GlobalIndexChecker on transactional index " + index,
-                    admin.getTableDescriptor(TableName.valueOf(index))
-                        .hasCoprocessor(GlobalIndexChecker.class.getName()));
+            Assert.assertFalse("Found GlobalIndexChecker on transactional index " + index,
+                admin.getDescriptor(TableName.valueOf(index))
+                    .hasCoprocessor(GlobalIndexChecker.class.getName()));
             }
         }
         for (String table : TRANSACTIONAL_TABLE_LIST) {
             if (table != null) {
-                Assert.assertFalse("Found IndexRegionObserver on transactional table",
-                    admin.getTableDescriptor(TableName.valueOf(table))
-                        .hasCoprocessor(IndexRegionObserver.class.getName()));
+            Assert.assertFalse("Found IndexRegionObserver on transactional table",
+                admin.getDescriptor(TableName.valueOf(table))
+                    .hasCoprocessor(IndexRegionObserver.class.getName()));
             }
         }
     }
@@ -434,7 +435,7 @@ public class ParameterizedIndexUpgradeToolIT extends BaseTest {
             throws IOException {
         if (mutable) {
             for (String table : tableList) {
-                HTableDescriptor indexDesc = admin.getTableDescriptor(TableName.valueOf(table));
+                TableDescriptor indexDesc = admin.getDescriptor(TableName.valueOf(table));
                 Assert.assertTrue("Can't find Indexer for " + table,
                     indexDesc.hasCoprocessor(Indexer.class.getName()));
                 Assert.assertFalse("Found IndexRegionObserver on " + table,
@@ -445,7 +446,7 @@ public class ParameterizedIndexUpgradeToolIT extends BaseTest {
         }
         for (String index : indexList) {
             Assert.assertFalse("Found GlobalIndexChecker on " + index,
-                admin.getTableDescriptor(TableName.valueOf(index))
+                admin.getDescriptor(TableName.valueOf(index))
                     .hasCoprocessor(GlobalIndexChecker.class.getName()));
         }
     }
