@@ -17,8 +17,8 @@
  */
 package org.apache.phoenix.execute;
 
-import static com.google.common.base.Preconditions.checkNotNull;
 import static org.apache.phoenix.query.QueryServices.SOURCE_OPERATION_ATTRIB;
+import static org.apache.phoenix.thirdparty.com.google.common.base.Preconditions.checkNotNull;
 import static org.apache.phoenix.monitoring.GlobalClientMetrics.GLOBAL_MUTATION_BATCH_FAILED_COUNT;
 import static org.apache.phoenix.monitoring.GlobalClientMetrics.GLOBAL_MUTATION_BATCH_SIZE;
 import static org.apache.phoenix.monitoring.GlobalClientMetrics.GLOBAL_MUTATION_BYTES;
@@ -44,6 +44,7 @@ import javax.annotation.Nonnull;
 import javax.annotation.concurrent.Immutable;
 
 import org.apache.hadoop.hbase.HConstants;
+import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Delete;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
@@ -105,8 +106,8 @@ import org.apache.phoenix.transaction.TransactionFactory.Provider;
 import org.apache.phoenix.util.EncodedColumnsUtil;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.IndexUtil;
-import org.apache.phoenix.util.KeyValueUtil;
 import org.apache.phoenix.util.LogUtil;
+import org.apache.phoenix.util.PhoenixKeyValueUtil;
 import org.apache.phoenix.util.SQLCloseable;
 import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.ServerUtil;
@@ -116,12 +117,12 @@ import org.apache.phoenix.util.WALAnnotationUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Preconditions;
-import com.google.common.base.Predicate;
-import com.google.common.collect.Iterators;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
-import com.google.common.collect.Sets;
+import org.apache.phoenix.thirdparty.com.google.common.base.Preconditions;
+import org.apache.phoenix.thirdparty.com.google.common.base.Predicate;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Iterators;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
 
 /**
  * Tracks the uncommitted state
@@ -215,7 +216,7 @@ public class MutationState implements SQLCloseable {
             this.mutations.put(table, mutations);
         }
         this.numRows = mutations.size();
-        this.estimatedSize = KeyValueUtil.getEstimatedRowMutationSize(this.mutations);
+        this.estimatedSize = PhoenixKeyValueUtil.getEstimatedRowMutationSize(this.mutations);
         throwIfTooBig();
     }
 
@@ -532,7 +533,7 @@ public class MutationState implements SQLCloseable {
         final Iterator<PTable> indexes = indexList.iterator();
         final List<Mutation> mutationList = Lists.newArrayListWithExpectedSize(values.size());
         final List<Mutation> mutationsPertainingToIndex = indexes.hasNext() ? Lists
-                .<Mutation> newArrayListWithExpectedSize(values.size()) : null;
+                .newArrayListWithExpectedSize(values.size()) : null;
         generateMutations(tableRef, mutationTimestamp, serverTimestamp, values, mutationList,
                 mutationsPertainingToIndex);
         return new Iterator<Pair<PTable, List<Mutation>>>() {
@@ -601,7 +602,8 @@ public class MutationState implements SQLCloseable {
                     throw new IllegalDataException(e);
                 }
                 return new Pair<PTable, List<Mutation>>(index,
-                        indexMutations == null ? Collections.<Mutation> emptyList() : indexMutations);
+                        indexMutations == null ? Collections.<Mutation> emptyList()
+                                : indexMutations);
             }
 
             @Override
@@ -745,8 +747,8 @@ public class MutationState implements SQLCloseable {
 
             private Iterator<Pair<byte[], List<Mutation>>> init() {
                 final Iterator<Pair<PTable, List<Mutation>>> mutationIterator =
-                        addRowMutations(current.getKey(), current.getValue(), mutationTimestamp,
-                                serverTimestamp, includeMutableIndexes, true);
+                        addRowMutations(current.getKey(), current.getValue(),
+                                mutationTimestamp, serverTimestamp, includeMutableIndexes, true);
                 return new Iterator<Pair<byte[], List<Mutation>>>() {
                     @Override
                     public boolean hasNext() {
@@ -877,7 +879,7 @@ public class MutationState implements SQLCloseable {
         long byteSize = 0;
         if (GlobalClientMetrics.isMetricsEnabled()) {
             for (Mutation mutation : mutations) {
-                byteSize += KeyValueUtil.calculateMutationDiskSize(mutation);
+                byteSize += PhoenixKeyValueUtil.calculateMutationDiskSize(mutation);
             }
         }
         GLOBAL_MUTATION_BYTES.update(byteSize);
@@ -907,11 +909,9 @@ public class MutationState implements SQLCloseable {
         private final PName hTableName;
         @Nonnull
         private final TableRef origTableRef;
-        //This is a phoenix/logical table name
         private final PTable pTable;
 
-        public TableInfo(boolean isDataTable, PName hTableName, TableRef origTableRef,
-                PTable pTable) {
+        public TableInfo(boolean isDataTable, PName hTableName, TableRef origTableRef, PTable pTable) {
             super();
             checkNotNull(hTableName);
             checkNotNull(origTableRef);
@@ -955,12 +955,11 @@ public class MutationState implements SQLCloseable {
             if (!hTableName.equals(other.hTableName)) return false;
             if (isDataTable != other.isDataTable) return false;
             if (!pTable.equals(other.pTable)) return false;
+
             return true;
         }
 
     }
-
-    @SuppressWarnings("deprecation")
     private void send(Iterator<TableRef> tableRefIterator) throws SQLException {
         int i = 0;
         long[] serverTimeStamps = null;
@@ -1005,8 +1004,10 @@ public class MutationState implements SQLCloseable {
                     Pair<PTable, List<Mutation>> pair = mutationsIterator.next();
                     PTable logicalTable = pair.getFirst();
                     List<Mutation> mutationList = pair.getSecond();
-                    TableInfo tableInfo = new TableInfo(isDataTable, logicalTable.getPhysicalName()
-                            , tableRef, logicalTable);
+
+                    TableInfo tableInfo = new TableInfo(isDataTable, logicalTable.getPhysicalName(),
+                            tableRef, logicalTable);
+
                     List<Mutation>
                             oldMutationList =
                             physicalTableMutationMap.put(tableInfo, mutationList);
@@ -1050,7 +1051,6 @@ public class MutationState implements SQLCloseable {
                         "Ignoring exception that happened during setting index verified value to verified=TRUE ",
                         ex);
             }
-
         }
     }
 
@@ -1125,7 +1125,7 @@ public class MutationState implements SQLCloseable {
                                 @Override
                                 public void doMutation() throws IOException {
                                     try {
-                                        finalHTable.batch(mutationBatch);
+                                        finalHTable.batch(mutationBatch, null);
                                     } catch (InterruptedException e) {
                                         Thread.currentThread().interrupt();
                                         throw new IOException(e);
@@ -1149,7 +1149,7 @@ public class MutationState implements SQLCloseable {
                                             .getErrorCode()) {
                                         try {
                                             connection.getQueryServices().clearTableRegionCache(
-                                                    finalHTable.getName().getName());
+                                                    finalHTable.getName());
                                             IndexMetaDataCacheClient.setMetaDataOnMutations(
                                                     connection, finalPTable, mutationBatch,
                                                     finalindexMetaDataPtr);
@@ -1164,7 +1164,7 @@ public class MutationState implements SQLCloseable {
                             }, iwe, connection, connection.getQueryServices().getProps());
                             shouldRetryIndexedMutation = false;
                         } else {
-                            hTable.batch(mutationBatch);
+                            hTable.batch(mutationBatch, null);
                         }
                         // remove each batch from the list once it gets applied
                         // so when failures happens for any batch we only start
@@ -1191,7 +1191,7 @@ public class MutationState implements SQLCloseable {
                     if (tableInfo.isDataTable()) {
                         numRows -= numMutations;
                         // recalculate the estimated size
-                        estimatedSize = KeyValueUtil.getEstimatedRowMutationSize(mutations);
+                        estimatedSize = PhoenixKeyValueUtil.getEstimatedRowMutationSize(mutations);
                     }
                 } catch (Exception e) {
                     mutationCommitTime = EnvironmentEdgeManager.currentTimeMillis() - startTime;
@@ -1210,7 +1210,7 @@ public class MutationState implements SQLCloseable {
                             String msg = "Swallowing exception and retrying after clearing meta cache on connection. "
                                     + inferredE;
                             LOGGER.warn(LogUtil.addCustomAnnotations(msg, connection));
-                            connection.getQueryServices().clearTableRegionCache(htableName);
+                            connection.getQueryServices().clearTableRegionCache(TableName.valueOf(htableName));
 
                             // add a new child span as this one failed
                             child.addTimelineAnnotation(msg);
@@ -1231,7 +1231,7 @@ public class MutationState implements SQLCloseable {
                                                 BaseScannerRegionObserver.REPLAY_ONLY_INDEX_WRITES
                                         );
                                     }
-                                    KeyValueUtil.setTimestamp(m, serverTimestamp);
+                                    PhoenixKeyValueUtil.setTimestamp(m, serverTimestamp);
                                 }
                                 shouldRetry = true;
                                 shouldRetryIndexedMutation = true;
@@ -1285,12 +1285,12 @@ public class MutationState implements SQLCloseable {
                 continue;
             }
             PTable logicalTable = tableInfo.getPTable();
-            if (tableInfo.getOrigTableRef().getTable()
-                    .isImmutableRows() && IndexUtil.isGlobalIndexCheckerEnabled(connection,
+            if (tableInfo.getOrigTableRef().getTable().isImmutableRows()
+                    && IndexUtil.isGlobalIndexCheckerEnabled(connection,
                     tableInfo.getHTableName())) {
+
                 byte[] emptyCF = SchemaUtil.getEmptyColumnFamily(logicalTable);
                 byte[] emptyCQ = EncodedColumnsUtil.getEmptyKeyValueInfo(logicalTable).getFirst();
-
                 List<Mutation> mutations = pair.getValue();
 
                 for (Mutation m : mutations) {
@@ -1345,7 +1345,7 @@ public class MutationState implements SQLCloseable {
      * Split the list of mutations into multiple lists. since a single row update can contain multiple mutations,
      * we only check if the current batch has exceeded the row or size limit for different rows,
      * so that mutations for a single row don't end up in different batches.
-     * 
+     *
      * @param allMutationList
      *            List of HBase mutations
      * @return List of lists of mutations
@@ -1361,13 +1361,13 @@ public class MutationState implements SQLCloseable {
         for (int i = 0; i < allMutationList.size(); ) {
             long sameRowBatchSize = 1L;
             Mutation mutation = allMutationList.get(i);
-            long sameRowMutationSizeBytes = KeyValueUtil.calculateMutationDiskSize(mutation);
+            long sameRowMutationSizeBytes = PhoenixKeyValueUtil.calculateMutationDiskSize(mutation);
             sameRowList.add(mutation);
             while (i + 1 < allMutationList.size() &&
                     Bytes.compareTo(allMutationList.get(i + 1).getRow(), mutation.getRow()) == 0) {
                 Mutation sameRowMutation = allMutationList.get(i + 1);
                 sameRowList.add(sameRowMutation);
-                sameRowMutationSizeBytes += KeyValueUtil.calculateMutationDiskSize(sameRowMutation);
+                sameRowMutationSizeBytes += PhoenixKeyValueUtil.calculateMutationDiskSize(sameRowMutation);
                 sameRowBatchSize++;
                 i++;
             }
