@@ -27,16 +27,20 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.concurrent.ConcurrentHashMap;
 
-import com.google.common.collect.ArrayListMultimap;
-import com.google.common.collect.ListMultimap;
-import com.google.common.collect.Lists;
+import org.apache.hadoop.hbase.ArrayBackedTag;
 import org.apache.hadoop.hbase.CellScanner;
 import org.apache.hadoop.hbase.PhoenixTagType;
+import org.apache.hadoop.hbase.PrivateCellUtil;
+import org.apache.hadoop.hbase.RawCell;
 import org.apache.hadoop.hbase.Tag;
-import org.apache.hadoop.hbase.TagRewriteCell;
+import org.apache.hadoop.hbase.TagUtil;
 import org.apache.phoenix.query.QueryServices;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ArrayListMultimap;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ListMultimap;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
@@ -44,7 +48,6 @@ import org.apache.hadoop.hbase.CoprocessorEnvironment;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HConstants.OperationStatusCode;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Delete;
@@ -54,15 +57,19 @@ import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.Scan;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
+import org.apache.hadoop.hbase.coprocessor.RegionCoprocessor;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
+import org.apache.hadoop.hbase.coprocessor.RegionObserver;
 import org.apache.hadoop.hbase.regionserver.MiniBatchOperationInProgress;
 import org.apache.hadoop.hbase.regionserver.OperationStatus;
 import org.apache.hadoop.hbase.regionserver.Region;
 import org.apache.hadoop.hbase.regionserver.RegionScanner;
-import org.apache.hadoop.hbase.regionserver.wal.WALEdit;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
+import org.apache.hadoop.hbase.wal.WALEdit;
 import org.apache.hadoop.hbase.wal.WALKey;
 import org.apache.htrace.Span;
 import org.apache.htrace.Trace;
@@ -74,6 +81,7 @@ import org.apache.phoenix.coprocessor.DelegateRegionCoprocessorEnvironment;
 import org.apache.phoenix.coprocessor.GlobalIndexRegionScanner;
 import org.apache.phoenix.filter.SkipScanFilter;
 import org.apache.phoenix.hbase.index.LockManager.RowLock;
+import org.apache.phoenix.hbase.index.builder.FatalIndexBuildingFailureException;
 import org.apache.phoenix.hbase.index.builder.IndexBuildManager;
 import org.apache.phoenix.hbase.index.builder.IndexBuilder;
 import org.apache.phoenix.hbase.index.covered.IndexMetaData;
@@ -115,7 +123,8 @@ import static org.apache.phoenix.coprocessor.IndexRebuildRegionScanner.removeCol
  * Phoenix always does batch mutations.
  * <p>
  */
-public class IndexRegionObserver extends CompatIndexRegionObserver {
+public class IndexRegionObserver extends CompatIndexRegionObserver implements RegionCoprocessor,
+    RegionObserver {
 
     private static final Logger LOG = LoggerFactory.getLogger(IndexRegionObserver.class);
     private static final OperationStatus IGNORE = new OperationStatus(OperationStatusCode.SUCCESS);
@@ -157,10 +166,13 @@ public class IndexRegionObserver extends CompatIndexRegionObserver {
       }
   }
 
+  private static boolean ignoreIndexRebuildForTesting  = false;
   private static boolean failPreIndexUpdatesForTesting = false;
   private static boolean failPostIndexUpdatesForTesting = false;
   private static boolean failDataTableUpdatesForTesting = false;
 
+  public static void setIgnoreIndexRebuildForTesting(boolean ignore) { ignoreIndexRebuildForTesting = ignore; }
+
   public static void setFailPreIndexUpdatesForTesting(boolean fail) { failPreIndexUpdatesForTesting = fail; }
 
   public static void setFailPostIndexUpdatesForTesting(boolean fail) { failPostIndexUpdatesForTesting = fail; }
@@ -299,39 +311,41 @@ public class IndexRegionObserver extends CompatIndexRegionObserver {
   private static final int DEFAULT_ROWLOCK_WAIT_DURATION = 30000;
   private static final int DEFAULT_CONCURRENT_MUTATION_WAIT_DURATION_IN_MS = 100;
 
+  @Override
+  public Optional<RegionObserver> getRegionObserver() {
+    return Optional.of(this);
+  }
+
   @Override
   public void start(CoprocessorEnvironment e) throws IOException {
       try {
-          final RegionCoprocessorEnvironment env = (RegionCoprocessorEnvironment) e;
-          String serverName = env.getRegionServerServices().getServerName().getServerName();
-          if (env.getConfiguration().getBoolean(CHECK_VERSION_CONF_KEY, true)) {
-              // make sure the right version <-> combinations are allowed.
-              String errormsg = Indexer.validateVersion(env.getHBaseVersion(), env.getConfiguration());
-              if (errormsg != null) {
-                  IOException ioe = new IOException(errormsg);
-                  env.getRegionServerServices().abort(errormsg, ioe);
-                  throw ioe;
-              }
-          }
-          this.builder = new IndexBuildManager(env);
-          // Clone the config since it is shared
-          DelegateRegionCoprocessorEnvironment indexWriterEnv = new DelegateRegionCoprocessorEnvironment(env, ConnectionType.INDEX_WRITER_CONNECTION);
-          // setup the actual index writer
-          // setup the actual index preWriter
-          this.preWriter = new IndexWriter(indexWriterEnv, serverName + "-index-preWriter", false);
-          if (env.getConfiguration().getBoolean(INDEX_LAZY_POST_BATCH_WRITE, INDEX_LAZY_POST_BATCH_WRITE_DEFAULT)) {
-              this.postWriter = new IndexWriter(indexWriterEnv, new LazyParallelWriterIndexCommitter(), serverName + "-index-postWriter", false);
-          }
-          else {
-              this.postWriter = this.preWriter;
+        final RegionCoprocessorEnvironment env = (RegionCoprocessorEnvironment) e;
+        String serverName = env.getServerName().getServerName();
+        if (env.getConfiguration().getBoolean(CHECK_VERSION_CONF_KEY, true)) {
+          // make sure the right version <-> combinations are allowed.
+          String errormsg = Indexer.validateVersion(env.getHBaseVersion(), env.getConfiguration());
+          if (errormsg != null) {
+              throw new FatalIndexBuildingFailureException(errormsg);
           }
+        }
 
-          this.rowLockWaitDuration = env.getConfiguration().getInt("hbase.rowlock.wait.duration",
+        this.builder = new IndexBuildManager(env);
+        // Clone the config since it is shared
+        DelegateRegionCoprocessorEnvironment indexWriterEnv = new DelegateRegionCoprocessorEnvironment(env, ConnectionType.INDEX_WRITER_CONNECTION);
+        // setup the actual index preWriter
+        this.preWriter = new IndexWriter(indexWriterEnv, serverName + "-index-preWriter", false);
+        if (env.getConfiguration().getBoolean(INDEX_LAZY_POST_BATCH_WRITE, INDEX_LAZY_POST_BATCH_WRITE_DEFAULT)) {
+            this.postWriter = new IndexWriter(indexWriterEnv, new LazyParallelWriterIndexCommitter(), serverName + "-index-postWriter", false);
+        }
+        else {
+            this.postWriter = this.preWriter;
+        }
+
+        this.rowLockWaitDuration = env.getConfiguration().getInt("hbase.rowlock.wait.duration",
                 DEFAULT_ROWLOCK_WAIT_DURATION);
           this.lockManager = new LockManager();
           this.concurrentMutationWaitDuration = env.getConfiguration().getInt("phoenix.index.concurrent.wait.duration.ms",
                   DEFAULT_CONCURRENT_MUTATION_WAIT_DURATION_IN_MS);
-
           // Metrics impl for the Indexer -- avoiding unnecessary indirection for hadoop-1/2 compat
           this.metricSource = MetricsIndexerSourceFactory.getInstance().getIndexerSource();
           setSlowThresholds(e.getConfiguration());
@@ -342,7 +356,6 @@ public class IndexRegionObserver extends CompatIndexRegionObserver {
               env.getConfiguration());
       } catch (NoSuchMethodError ex) {
           disabled = true;
-          super.start(e);
           LOG.error("Must be too early a version of HBase. Disabled coprocessor ", ex);
       }
   }
@@ -380,39 +393,38 @@ public class IndexRegionObserver extends CompatIndexRegionObserver {
   }
 
   /**
-     * We use an Increment to serialize the ON DUPLICATE KEY clause so that the HBase plumbing
-     * sets up the necessary locks and mvcc to allow an atomic update. The Increment is not a
-     * real increment, though, it's really more of a Put. We translate the Increment into a
-     * list of mutations, at most a single Put and Delete that are the changes upon executing
-     * the list of ON DUPLICATE KEY clauses for this row.
+   * We use an Increment to serialize the ON DUPLICATE KEY clause so that the HBase plumbing
+   * sets up the necessary locks and mvcc to allow an atomic update. The Increment is not a
+   * real increment, though, it's really more of a Put. We translate the Increment into a
+   * list of mutations, at most a single Put and Delete that are the changes upon executing
+   * the list of ON DUPLICATE KEY clauses for this row.
    */
   @Override
   public Result preIncrementAfterRowLock(final ObserverContext<RegionCoprocessorEnvironment> e,
-                                           final Increment inc) throws IOException {
+          final Increment inc) throws IOException {
       long start = EnvironmentEdgeManager.currentTimeMillis();
       try {
           List<Mutation> mutations = this.builder.executeAtomicOp(inc);
           if (mutations == null) {
               return null;
           }
+
           // Causes the Increment to be ignored as we're committing the mutations
           // ourselves below.
           e.bypass();
-          e.complete();
           // ON DUPLICATE KEY IGNORE will return empty list if row already exists
           // as no action is required in that case.
           if (!mutations.isEmpty()) {
               Region region = e.getEnvironment().getRegion();
               // Otherwise, submit the mutations directly here
-              region.batchMutate(mutations.toArray(new Mutation[0]), HConstants.NO_NONCE,
-                      HConstants.NO_NONCE);
+                region.batchMutate(mutations.toArray(new Mutation[0]));
           }
           return Result.EMPTY_RESULT;
       } catch (Throwable t) {
           throw ServerUtil.createIOException(
                   "Unable to process ON DUPLICATE IGNORE for " +
-                          e.getEnvironment().getRegion().getRegionInfo().getTable().getNameAsString() +
-                          "(" + Bytes.toStringBinary(inc.getRow()) + ")", t);
+                  e.getEnvironment().getRegion().getRegionInfo().getTable().getNameAsString() +
+                  "(" + Bytes.toStringBinary(inc.getRow()) + ")", t);
       } finally {
           long duration = EnvironmentEdgeManager.currentTimeMillis() - start;
           if (duration >= slowIndexPrepareThreshold) {
@@ -685,7 +697,8 @@ public class IndexRegionObserver extends CompatIndexRegionObserver {
         }
     }
     /**
-     * Retrieve the the last committed data row state.
+     * Retrieve the the last committed data row state. This method is called only for regular data mutations since for
+     * rebuild (i.e., index replay) mutations include all row versions.
      */
     private void getCurrentRowStates(ObserverContext<RegionCoprocessorEnvironment> c,
                                      BatchMutateContext context) throws IOException {
@@ -1035,14 +1048,21 @@ public class IndexRegionObserver extends CompatIndexRegionObserver {
             if (sourceOpAttr == null) {
                 continue;
             }
-            Tag sourceOpTag = new Tag(PhoenixTagType.SOURCE_OPERATION_TAG_TYPE, sourceOpAttr);
+            Tag sourceOpTag = new ArrayBackedTag(PhoenixTagType.SOURCE_OPERATION_TAG_TYPE,
+                    sourceOpAttr);
             List<Cell> updatedCells = new ArrayList<>();
             for (CellScanner cellScanner = m.cellScanner(); cellScanner.advance();) {
                 Cell cell = cellScanner.current();
-                List<Tag> tags = Tag.asList(cell.getTagsArray(),
-                        cell.getTagsOffset(), cell.getTagsLength());
+                RawCell rawCell = (RawCell)cell;
+                List<Tag> tags = new ArrayList<>();
+                Iterator<Tag> tagsIterator = rawCell.getTags();
+                while (tagsIterator.hasNext()) {
+                    tags.add(tagsIterator.next());
+                }
                 tags.add(sourceOpTag);
-                Cell updatedCell = new TagRewriteCell(cell, Tag.fromList(tags));
+                // TODO: PrivateCellUtil's IA is Private. HBASE-25328 adds a builder method
+                // TODO: for creating Tag which will be LP with IA.coproc
+                Cell updatedCell = PrivateCellUtil.createCell(cell, tags);
                 updatedCells.add(updatedCell);
             }
             m.getFamilyCellMap().clear();
@@ -1190,20 +1210,20 @@ public class IndexRegionObserver extends CompatIndexRegionObserver {
 
   /**
    * Enable indexing on the given table
-   * @param desc {@link HTableDescriptor} for the table on which indexing should be enabled
-   * @param builder class to use when building the index for this table
-   * @param properties map of custom configuration options to make available to your
+   * @param descBuilder {@link TableDescriptor} for the table on which indexing should be enabled
+ * @param builder class to use when building the index for this table
+ * @param properties map of custom configuration options to make available to your
    *          {@link IndexBuilder} on the server-side
-   * @param priority TODO
+ * @param priority TODO
    * @throws IOException the Indexer coprocessor cannot be added
    */
-  public static void enableIndexing(HTableDescriptor desc, Class<? extends IndexBuilder> builder,
-                                    Map<String, String> properties, int priority) throws IOException {
-      if (properties == null) {
-          properties = new HashMap<String, String>();
-      }
-      properties.put(IndexRegionObserver.INDEX_BUILDER_CONF_KEY, builder.getName());
-      desc.addCoprocessor(IndexRegionObserver.class.getName(), null, priority, properties);
+  public static void enableIndexing(TableDescriptorBuilder descBuilder, Class<? extends IndexBuilder> builder,
+      Map<String, String> properties, int priority) throws IOException {
+    if (properties == null) {
+      properties = new HashMap<String, String>();
+    }
+    properties.put(Indexer.INDEX_BUILDER_CONF_KEY, builder.getName());
+     descBuilder.addCoprocessor(IndexRegionObserver.class.getName(), null, priority, properties);
   }
 }
 
