@@ -17,8 +17,8 @@
  */
 package org.apache.phoenix.util;
 
-import static com.google.common.base.Preconditions.checkNotNull;
-import static com.google.common.base.Preconditions.checkArgument;
+import static org.apache.phoenix.thirdparty.com.google.common.base.Preconditions.checkNotNull;
+import static org.apache.phoenix.thirdparty.com.google.common.base.Preconditions.checkArgument;
 import static org.apache.phoenix.schema.types.PDataType.ARRAY_TYPE_SUFFIX;
 
 import java.io.File;
@@ -51,10 +51,9 @@ import org.apache.phoenix.thirdparty.org.apache.commons.cli.Option;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.Options;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.ParseException;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.PosixParser;
-import org.apache.commons.lang.StringEscapeUtils;
+import org.apache.commons.lang3.StringEscapeUtils;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.util.Pair;
@@ -93,12 +92,12 @@ import org.apache.phoenix.schema.TableNotFoundException;
 import org.apache.phoenix.schema.ValueBitSet;
 import org.apache.phoenix.schema.types.PDataType;
 
-import com.google.common.base.Function;
-import com.google.common.base.Joiner;
-import com.google.common.base.Splitter;
-import com.google.common.collect.ImmutableList;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.base.Function;
+import org.apache.phoenix.thirdparty.com.google.common.base.Joiner;
+import org.apache.phoenix.thirdparty.com.google.common.base.Splitter;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 /**
  *
@@ -360,8 +359,8 @@ public class PhoenixRuntime {
      * @throws SQLException
      */
     @Deprecated
-    public static List<KeyValue> getUncommittedData(Connection conn) throws SQLException {
-        Iterator<Pair<byte[],List<KeyValue>>> iterator = getUncommittedDataIterator(conn);
+    public static List<Cell> getUncommittedData(Connection conn) throws SQLException {
+        Iterator<Pair<byte[],List<Cell>>> iterator = getUncommittedDataIterator(conn);
         if (iterator.hasNext()) {
             return iterator.next().getSecond();
         }
@@ -375,7 +374,7 @@ public class PhoenixRuntime {
      * @return the list of HBase mutations for uncommitted data
      * @throws SQLException
      */
-    public static Iterator<Pair<byte[],List<KeyValue>>> getUncommittedDataIterator(Connection conn) throws SQLException {
+    public static Iterator<Pair<byte[],List<Cell>>> getUncommittedDataIterator(Connection conn) throws SQLException {
         return getUncommittedDataIterator(conn, false);
     }
 
@@ -386,10 +385,10 @@ public class PhoenixRuntime {
      * @return the list of HBase mutations for uncommitted data
      * @throws SQLException
      */
-    public static Iterator<Pair<byte[],List<KeyValue>>> getUncommittedDataIterator(Connection conn, boolean includeMutableIndexes) throws SQLException {
+    public static Iterator<Pair<byte[],List<Cell>>> getUncommittedDataIterator(Connection conn, boolean includeMutableIndexes) throws SQLException {
         final PhoenixConnection pconn = conn.unwrap(PhoenixConnection.class);
         final Iterator<Pair<byte[],List<Mutation>>> iterator = pconn.getMutationState().toMutations(includeMutableIndexes);
-        return new Iterator<Pair<byte[],List<KeyValue>>>() {
+        return new Iterator<Pair<byte[],List<Cell>>>() {
 
             @Override
             public boolean hasNext() {
@@ -397,18 +396,18 @@ public class PhoenixRuntime {
             }
 
             @Override
-            public Pair<byte[], List<KeyValue>> next() {
+            public Pair<byte[], List<Cell>> next() {
                 Pair<byte[],List<Mutation>> pair = iterator.next();
-                List<KeyValue> keyValues = Lists.newArrayListWithExpectedSize(pair.getSecond().size() * 5); // Guess-timate 5 key values per row
+                List<Cell> keyValues = Lists.newArrayListWithExpectedSize(pair.getSecond().size() * 5); // Guess-timate 5 key values per row
                 for (Mutation mutation : pair.getSecond()) {
                     for (List<Cell> keyValueList : mutation.getFamilyCellMap().values()) {
                         for (Cell keyValue : keyValueList) {
-                            keyValues.add(org.apache.hadoop.hbase.KeyValueUtil.ensureKeyValue(keyValue));
+                            keyValues.add(PhoenixKeyValueUtil.maybeCopyCell(keyValue));
                         }
                     }
                 }
                 Collections.sort(keyValues, pconn.getKeyValueBuilder().getKeyValueComparator());
-                return new Pair<byte[], List<KeyValue>>(pair.getFirst(),keyValues);
+                return new Pair<byte[], List<Cell>>(pair.getFirst(),keyValues);
             }
 
             @Override
@@ -1093,7 +1092,7 @@ public class PhoenixRuntime {
      * of their values in the object array.
      * @return values encoded in a byte array 
      * @throws SQLException
-     * @see {@link #decodeValues(Connection, String, byte[], List)}
+     * @see decodeValues(Connection, String, byte[], List)
      */
     @Deprecated
     public static byte[] encodeValues(Connection conn, String fullTableName, Object[] values, List<Pair<String, String>> columns) throws SQLException {
@@ -1159,7 +1158,7 @@ public class PhoenixRuntime {
      * of their values in the object array.
      * @return values encoded in a byte array 
      * @throws SQLException
-     * @see {@link #decodeValues(Connection, String, byte[], List)}
+     * @see decodeValues(Connection, String, byte[], List)
      */
     public static byte[] encodeColumnValues(Connection conn, String fullTableName, Object[] values, List<Pair<String, String>> columns) throws SQLException {
         PTable table = getTable(conn, fullTableName);
@@ -1410,11 +1409,12 @@ public class PhoenixRuntime {
      *    requestReadMetrics = PhoenixRuntime.getRequestReadMetrics(rs);
      *    PhoenixRuntime.resetMetrics(rs);
      * }
+     * }
      * </pre>
      * 
      * @param rs
      *            result set to get the metrics for
-     * @return a map of (table name) -> (map of (metric name) -> (metric value))
+     * @return a map of {@code (table name) -> (map of (metric name) -> (metric value)) }
      * @throws SQLException
      */
     public static Map<String, Map<MetricType, Long>> getRequestReadMetricInfo(ResultSet rs) throws SQLException {
@@ -1444,11 +1444,12 @@ public class PhoenixRuntime {
      *    requestReadMetrics = PhoenixRuntime.getRequestReadMetrics(rs);
      *    PhoenixRuntime.resetMetrics(rs);
      * }
+     * }
      * </pre>
      * 
      * @param rs
      *            result set to get the metrics for
-     * @return a map of metric name -> metric value
+     * @return a map of {@code  metric name -> metric value }
      * @throws SQLException
      */
     public static Map<MetricType, Long> getOverAllReadRequestMetricInfo(ResultSet rs) throws SQLException {
@@ -1483,11 +1484,12 @@ public class PhoenixRuntime {
      *    mutationReadMetrics = PhoenixRuntime.getReadMetricsForMutationsSinceLastReset(conn);
      *    PhoenixRuntime.resetMetrics(rs);
      * }
+     * }
      * </pre>
      *  
      * @param conn
      *            connection to get the metrics for
-     * @return a map of (table name) -> (map of (metric name) -> (metric value))
+     * @return a map of {@code  (table name) -> (map of (metric name) -> (metric value)) }
      * @throws SQLException
      */
     public static Map<String, Map<MetricType, Long>> getWriteMetricInfoForMutationsSinceLastReset(Connection conn) throws SQLException {
@@ -1522,10 +1524,11 @@ public class PhoenixRuntime {
      *    mutationReadMetrics = PhoenixRuntime.getReadMetricsForMutationsSinceLastReset(conn);
      *    PhoenixRuntime.resetMetrics(rs);
      * }
+     * }
      * </pre> 
      * @param conn
      *            connection to get the metrics for
-     * @return  a map of (table name) -> (map of (metric name) -> (metric value))
+     * @return  a map of {@code  (table name) -> (map of (metric name) -> (metric value)) }
      * @throws SQLException
      */
     public static Map<String, Map<MetricType, Long>> getReadMetricInfoForMutationsSinceLastReset(Connection conn) throws SQLException {
@@ -1542,7 +1545,7 @@ public class PhoenixRuntime {
     /**
      * Reset the read metrics collected in the result set.
      * 
-     * @see {@link #getRequestReadMetrics(ResultSet)} {@link #getOverAllReadRequestMetrics(ResultSet)}
+     * @see  #getRequestReadMetrics(ResultSet) #getOverAllReadRequestMetrics(ResultSet)
      * @param rs
      * @throws SQLException
      */
@@ -1554,7 +1557,7 @@ public class PhoenixRuntime {
     /**
      * Reset the mutation and reads-for-mutations metrics collected in the connection.
      * 
-     * @see {@link #getReadMetricsForMutationsSinceLastReset(Connection)} {@link #getWriteMetricsForMutationsSinceLastReset(Connection)}
+     * @see #getReadMetricsForMutationsSinceLastReset(Connection) #getWriteMetricsForMutationsSinceLastReset(Connection)
      * @param conn
      * @throws SQLException
      */
